@@ -1,4 +1,3 @@
-# $Id$
 package Module::Release::Prereq;
 
 use strict;
@@ -6,9 +5,9 @@ use warnings;
 use base qw(Exporter);
 use vars qw($VERSION);
 
-our @EXPORT = qw( check_prereqs );
+our @EXPORT = qw( check_prereqs _get_prereq_ignore_list );
 
-$VERSION = '2.00_07';
+$VERSION = '2.04_01';
 
 =head1 NAME
 
@@ -35,11 +34,18 @@ It looks in local_name to get the name of the distribution file.
 
 sub check_prereqs
 	{
+	eval "require Test::Prereq; 1 " or
+		$_[0]->_die( "You need Test::Prereq to check prereqs" );
+
 	$_[0]->_print( "Checking prereqs... " );
 	
 	my $perl = $_[0]->{perl};
 	
-	my $messages = $_[0]->run( "$perl -MTest::Prereq -eprereq_ok" );
+	my @ignore = $_[0]->_get_prereq_ignore_list;
+	
+	my $messages = $_[0]->run( 
+		qq|$perl -MTest::Prereq -e "prereq_ok( undef, undef, [ qw(@ignore) ] )"| 
+		);
 	
 	$_[0]->_die( "Prereqs had a problem:\n$messages\n" )
 		unless $messages =~ m/^ok 1 - Prereq test/m;
@@ -47,6 +53,10 @@ sub check_prereqs
 	$_[0]->_print( "done\n" );
 	}
 
+sub _get_prereq_ignore_list
+	{	
+	my @ignore = split /\s+/, $_[0]->config->ignore_prereqs;
+	}
 
 =back
 
@@ -66,7 +76,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2008, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
