@@ -1,4 +1,3 @@
-# $Id$
 package Module::Release;
 
 =head1 NAME
@@ -23,7 +22,7 @@ use warnings;
 no warnings;
 use vars qw($VERSION);
 
-$VERSION = '2.00_07';
+$VERSION = '2.04_01';
 
 use Carp;
 use File::Spec;
@@ -131,6 +130,10 @@ Your SourceForge account (i.e. login) name.
 
 Set this to a true value to enable passive FTP.
 
+=item ignore_prereqs
+
+A whitespace separated list of modules for C<Test::Prereq> to ignore.
+
 =back
 
 =head2 Methods
@@ -165,6 +168,7 @@ sub new
 
 	if( $config->release_subclass )
 		{
+		$self->_warn( "Use of release_subclass is deprecated" );
 		$self->_die( "release_subclass is the same class! Don't do that!" )
 			if $config->release_subclass eq $class;
 		my $subclass_self = $self->_handle_subclass(
@@ -209,18 +213,20 @@ sub _set_defaults
 	my( $self, %params ) = @_;
 
 	my $defaults = {
-			'Makefile.PL' => 'Makefile.PL',
-			'Makefile'    => 'Makefile',
-			make          => $Config::Config{make},
-			manifest      => 'MANIFEST',
-			debug         => $ENV{RELEASE_DEBUG} || 0,
-			local_file    => undef,
-			remote_file   => undef,
-			output_fh     => *STDOUT{IO},
-			debug_fh      => *STDERR{IO},
-			null_fh       => IO::Null->new(),
-			quiet         => 0,
-
+			'Makefile.PL'  => 'Makefile.PL',
+			'Makefile'     => 'Makefile',
+			make           => $Config::Config{make},
+			manifest       => 'MANIFEST',
+			debug          => $ENV{RELEASE_DEBUG} || 0,
+			local_file     => undef,
+			remote_file    => undef,
+			output_fh      => *STDOUT{IO},
+			debug_fh       => *STDERR{IO},
+			null_fh        => IO::Null->new(),
+			quiet          => 0,
+			devnull        => File::Spec->devnull,
+			ignore_prereqs => '',
+			
 			%params,
 		   };
 
@@ -826,7 +832,7 @@ sub dist
 		return;
 		}
 
-	my $messages = $self->run( "$self->{make} dist 2>&1 < /dev/null" );
+	my $messages = $self->run( "$self->{make} dist 2>&1 < $self->{devnull}" );
 	$self->_debug( "messages are [$messages]" );
 
 	# If the distro isn't already set, try to guess it
@@ -1358,7 +1364,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2008 brian d foy.  All rights reserved.
+Copyright (c) 2002-2009 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
