@@ -1,4 +1,3 @@
-# $Id$
 package Module::Release::SVN;
 
 use strict;
@@ -10,7 +9,7 @@ use Carp;
 
 our @EXPORT = qw(check_vcs vcs_tag make_vcs_tag);
 
-$VERSION = '2.00_07';
+$VERSION = '2.04_01';
 
 =head1 NAME
 
@@ -200,13 +199,13 @@ sub vcs_tag
 		return;
 		}
 
-	my $tag = $self->make_cvs_tag;
+	my $tag = $self->make_vcs_tag;
 
 	push @tag_url, $tag;
 	$tag_url->path_segments(@tag_url);
 	$self->_print( "Tagging release to $tag_url\n" );
 
-	$self->run( 'svn copy $trunk_url $tag_url' );
+	$self->run( "svn copy $trunk_url $tag_url" );
 
 	if ( $? )
 		{
@@ -267,7 +266,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2008, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
